summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates/opieinput/simpleimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/app_templates/opieinput/simpleimpl.cpp')
-rw-r--r--languages/cpp/app_templates/opieinput/simpleimpl.cpp64
1 files changed, 32 insertions, 32 deletions
diff --git a/languages/cpp/app_templates/opieinput/simpleimpl.cpp b/languages/cpp/app_templates/opieinput/simpleimpl.cpp
index 6da986eb..db2e4285 100644
--- a/languages/cpp/app_templates/opieinput/simpleimpl.cpp
+++ b/languages/cpp/app_templates/opieinput/simpleimpl.cpp
@@ -1,43 +1,43 @@
-#include <qwidget.h>
-#include <qcheckbox.h>
-#include <qlabel.h>
-#include <qsignalmapper.h>
-#include <qpushbutton.h>
+#include <tqwidget.h>
+#include <tqcheckbox.h>
+#include <tqlabel.h>
+#include <tqsignalmapper.h>
+#include <tqpushbutton.h>
#include <qpe/resource.h>
#include "%{APPNAMELC}.h"
-%{APPNAME}::%{APPNAME}(QWidget* par, WFlags fl )
- : QHBox(par, "name", fl )
+%{APPNAME}::%{APPNAME}(TQWidget* par, WFlags fl )
+ : TQHBox(par, "name", fl )
{
- QCheckBox *box1 = new QCheckBox(tr("Alt"),this);
- connect(box1,SIGNAL(toggled(bool)),
- this,SLOT(slotAlt(bool)));
+ TQCheckBox *box1 = new TQCheckBox(tr("Alt"),this);
+ connect(box1,TQT_SIGNAL(toggled(bool)),
+ this,TQT_SLOT(slotAlt(bool)));
m_alt = box1;
- box1 = new QCheckBox(tr("Shift"),this );
- connect(box1,SIGNAL(toggled(bool)),
- this,SLOT(slotShift(bool)));
+ box1 = new TQCheckBox(tr("Shift"),this );
+ connect(box1,TQT_SIGNAL(toggled(bool)),
+ this,TQT_SLOT(slotShift(bool)));
m_shi = box1;
- box1 = new QCheckBox(tr("Ctrl","Control Shortcut on keyboard"),this );
- connect(box1,SIGNAL(toggled(bool)),
- this,SLOT(slotCtrl(bool)));
+ box1 = new TQCheckBox(tr("Ctrl","Control Shortcut on keyboard"),this );
+ connect(box1,TQT_SIGNAL(toggled(bool)),
+ this,TQT_SLOT(slotCtrl(bool)));
m_ctrl = box1;
- QSignalMapper *map = new QSignalMapper(this);
- QPushButton *btn = new QPushButton("a",this);
+ TQSignalMapper *map = new TQSignalMapper(this);
+ TQPushButton *btn = new TQPushButton("a",this);
map->setMapping(btn,0);
- connect(btn,SIGNAL(clicked()),map,SLOT(map()));
+ connect(btn,TQT_SIGNAL(clicked()),map,TQT_SLOT(map()));
- btn = new QPushButton("b",this);
+ btn = new TQPushButton("b",this);
map->setMapping(btn,1);
- connect(btn,SIGNAL(clicked()),map,SLOT(map()));
+ connect(btn,TQT_SIGNAL(clicked()),map,TQT_SLOT(map()));
- btn = new QPushButton("c",this);
+ btn = new TQPushButton("c",this);
map->setMapping(btn,2);
- connect(btn,SIGNAL(clicked()),map,SLOT(map()));
+ connect(btn,TQT_SIGNAL(clicked()),map,TQT_SLOT(map()));
- connect(map,SIGNAL(mapped(int)),
- this,SLOT(slotKey(int)));
+ connect(map,TQT_SIGNAL(mapped(int)),
+ this,TQT_SLOT(slotKey(int)));
resetState();
}
@@ -102,7 +102,7 @@ void %{APPNAME}::slotCtrl(bool b){
delete m_icn;
}
-QWidget *%{APPNAME}Impl::inputMethod( QWidget *parent, Qt::WFlags f )
+TQWidget *%{APPNAME}Impl::inputMethod( TQWidget *parent, Qt::WFlags f )
{
if ( !m_pickboard )
m_pickboard = new %{APPNAME}( parent, f );
@@ -115,22 +115,22 @@ void %{APPNAME}Impl::resetState()
m_pickboard->resetState();
}
-QPixmap *%{APPNAME}Impl::icon()
+TQPixmap *%{APPNAME}Impl::icon()
{
if ( !m_icn )
- m_icn = new QPixmap(Resource::loadPixmap("Tux"));
+ m_icn = new TQPixmap(Resource::loadPixmap("Tux"));
return m_icn;
}
-QString %{APPNAME}Impl::name()
+TQString %{APPNAME}Impl::name()
{
- return QObject::tr("Example Input");
+ return TQObject::tr("Example Input");
}
-void %{APPNAME}Impl::onKeyPress( QObject *receiver, const char *slot )
+void %{APPNAME}Impl::onKeyPress( TQObject *receiver, const char *slot )
{
if ( m_pickboard )
- QObject::connect( m_pickboard, SIGNAL(key(ushort,ushort,ushort,bool,bool)), receiver, slot );
+ TQObject::connect( m_pickboard, TQT_SIGNAL(key(ushort,ushort,ushort,bool,bool)), receiver, slot );
}
#ifndef QT_NO_COMPONENT